@@ -333,7 +333,7 @@ class OfficeRegistratorFacultyLink(Base):
     # Специалист ОР
     office_registrator_id = Column(ForeignKey(
         'univer_office_registrator.office_registrator_id'), primary_key=True)
-    office_registrator = relationship('OfficeRegistrator')
+    office_registrator = relationship('OfficeRegistrator', backref='faculties')
 
     # Факультет
     faculty_id = Column(ForeignKey(
