@@ -17,8 +17,6 @@ class TestOfficeRegistrator(unittest.TestCase):
         session = Session()
         office_registrator = session.query(OfficeRegistrator).first()
         print(f'office_registrator: {office_registrator}')
-        office_registrator_faculties = session.query(OfficeRegistratorFacultyLink).filter(
-            OfficeRegistratorFacultyLink.office_registrator_id == office_registrator.id)
 
-        for office_registrator in office_registrator_faculties:
-            print(f'faculty: {office_registrator.faculty}')
+        for faculty_links in office_registrator.faculties:
+            print(f'faculty: {faculty_links.faculty}')
